/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.gobblin.data.management.version;

import java.util.Set;

import org.apache.hadoop.fs.Path;

import com.google.common.collect.Sets;

import lombok.Getter;


/**
 * Dataset version using {@link java.lang.String} as version.
 */
@Getter
public class StringDatasetVersion implements FileSystemDatasetVersion {

  protected final String version;
  protected final Path path;

  public StringDatasetVersion(String version, Path path) {
    this.version = version;
    this.path = path;
  }

  @Override
  public int compareTo(FileSystemDatasetVersion other) {
    StringDatasetVersion otherAsString = (StringDatasetVersion) other;
    return this.version.equals(otherAsString.version) ? this.path.compareTo(otherAsString.path) : this.version
        .compareTo(otherAsString.version);
  }

  @Override
  public boolean equals(Object obj) {
    return obj != null && this.getClass().equals(obj.getClass()) && compareTo((StringDatasetVersion) obj) == 0;
  }

  @Override
  public int hashCode() {
    return this.path.hashCode() + this.version.hashCode();
  }

  @Override
  public String toString() {
    return this.version;
  }

  @Override
  public Set<Path> getPaths() {
    return Sets.newHashSet(this.path);
  }
}
