/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.gobblin.metastore;

import java.util.Properties;
import javax.sql.DataSource;

import com.google.inject.AbstractModule;
import com.google.inject.name.Names;


/**
 * A Guice module defining the dependencies used by the metastore module.
 *
 * @author Yinan Li
 */
public class MetaStoreModule extends AbstractModule {

  private final Properties properties;

  public MetaStoreModule(Properties properties) {
    this.properties = properties;
  }

  @Override
  protected void configure() {
    bind(Properties.class).annotatedWith(Names.named("dataSourceProperties")).toInstance(this.properties);
    bind(DataSource.class).toProvider(JobHistoryDataSourceProvider.class);
    bind(JobHistoryStore.class).to(DatabaseJobHistoryStore.class);
  }
}
